Crate bitfield [−] [src]
This crate provides macros to generate bitfield-like struct.
See the documentation of the macros for how to use them.
Examples and tests are also a great way to understand how to use these macros.
Macros
| bitfield |
Combines |
| bitfield_debug |
Generates a |
| bitfield_fields |
Declares the fields of struct. |
| bitfield_struct |
Declares a struct that implements |
Traits
| Bit |
A trait to get or set a single bit. |
| BitRange |
A trait to get or set ranges of bits. |